@@ -2,9 +2,10 @@ package Test::Builder::Trace;
 use strict;
 use warnings;
 
-use Test::Builder::Util qw/accessor accessors is_tester/;
+use Test::Builder::Util qw/accessor accessors is_tester try/;
 use Test::Builder::Trace::Frame;
 use List::Util qw/first/;
+use Encode();
 
 accessor anointed    => sub { [] };
 accessor full        => sub { [] };
@@ -70,10 +71,46 @@ sub new {
     }
 
     $current->report;
+    $current->encoding; # Generate this now
 
     return $self;
 }
 
+sub encoding {
+    my $self = shift;
+
+    unless($self->{encoding}) {
+        return unless @{$self->anointed};
+        $self->{encoding} = $self->anointed->[0]->package->TB_TESTER_META->{encoding};
+    }
+
+    return $self->{encoding};
+}
+
+sub decode {
+    my $self = shift;
+
+    my $current = $self;
+    while($current) {
+        $current->_decode;
+        $current = $current->parent;
+    }
+
+    return;
+}
+
+sub _decode {
+    my $self = shift;
+    my $encoding = $self->encoding || return;
+    return if $encoding eq 'legacy';
+
+    for my $frame (@{$self->full}) {
+        my $file = $frame->file;
+        try { $file = Encode::decode($encoding, "$file", Encode::FB_CROAK) } || next;
+        $frame->file($file);
+    }
+}
+
 sub todo_package {
     my $self = shift;
     return $self->report->package          if $self->report && $self->report->todo;
@@ -205,6 +242,14 @@ trace.
 
 =back
 
+=item $trace->decode
+
+This will iterate over every L<Test::Builder::Trace::Frame> object and
+translate the filename into the tap_encoding that was set when the stack was
+created. This can be useful in cases where the filename is in utf8 since perl
+will not make that translation for you due to uncertainties about the
+filesystem on any given platform.
+
 =head1 STACKS
 
 All stacks are arrayrefs containing L<Test::Builder::Trace::Frame> objects.
